@@ -61,5 +61,5 @@
 #define DISABLE_COPY(Class) \
     Class(const Class &) = delete; \
     Class &operator=(const Class &) = delete; \
-    Class(Class &&) = delete; \
-    Class &operator=(Class &&) = delete
+    Class(Class &&) DIGIDOCPP_NOEXCEPT = delete; \
+    Class &operator=(Class &&) DIGIDOCPP_NOEXCEPT = delete
